@@ -1,9 +1,11 @@
 package Finance::QuoteHist::DailyFinance;
 
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 use Carp;
 
+$VERSION = "1.00";
+
 use constant DEBUG => 0;
 
 use Finance::QuoteHist::Generic;
