@@ -1,9 +1,11 @@
 package Finance::QuoteHist::Yahoo;
 
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 use Carp;
 
+$VERSION = "1.26";
+
 use Finance::QuoteHist::Generic;
 @ISA = qw(Finance::QuoteHist::Generic);
 
@@ -278,7 +280,7 @@ Matthew P. Sisk, E<lt>F<sisk@mojotoad.com>E<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2014 Matthew P. Sisk. All rights reserved. All wrongs
+Copyright (c) 2000-2017 Matthew P. Sisk. All rights reserved. All wrongs
 revenged. This program is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
 
